@@ -1,16 +1,22 @@
 # Copyright (c) Metakernel Development Team.
 # Distributed under the terms of the Modified BSD License.
 
-from IPython.display import FileLinks
-from metakernel import Magic, option
 import os
 
+from IPython.display import FileLinks
+
+from metakernel import Magic, option
+
+
 class LSMagic(Magic):
     @option(
-        "-r", "--recursive", action="store_true", default=False,
-        help='recursively descend into subdirectories'
+        "-r",
+        "--recursive",
+        action="store_true",
+        default=False,
+        help="recursively descend into subdirectories",
     )
-    def line_ls(self, path=".", recursive=False):
+    def line_ls(self, path=".", recursive=False) -> None:
         """
         %ls PATH - list files and directories under PATH
 
@@ -27,5 +33,5 @@ class LSMagic(Magic):
         return self.retval
 
 
-def register_magics(kernel):
-   kernel.register_magics(LSMagic)
+def register_magics(kernel) -> None:
+    kernel.register_magics(LSMagic)
